Get Directed Discards
get_discards.RdEstimate directed fishery discards by sex using subtraction method
Arguments
- retained_catch
NULL. Output of
get_retaied_catch().- total_catch
NULL. Output of
get_total_catch(). 'by' argument could be anything as long as group or sex is included.- stock
NULL. Character string stock abbreviation: BSSC, WBT, EBT, BBRKC, EAG, WAG, PIGKC, SMBKC, PIBKC, PIRKC, WAIRKC.